/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id$
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AQOFXCONNECT_VERSION_H
#define AQOFXCONNECT_VERSION_H

#define AQOFXCONNECT_VERSION_MAJOR 5
#define AQOFXCONNECT_VERSION_MINOR 0
#define AQOFXCONNECT_VERSION_PATCHLEVEL 28
#define AQOFXCONNECT_VERSION_BUILD 0
#define AQOFXCONNECT_VERSION_TAG "beta"
#define AQOFXCONNECT_VERSION_FULL_STRING "5.0.28.0beta"
#define AQOFXCONNECT_VERSION_STRING "5.0.28"



#endif /* AQOFXCONNECT_VERSION_H */


